<p align="center">
<img src="{icon_url}" width="100%">
<br>
<h1 align="center">{title}</h1>
<h2 align="center">
  {subtitle}
<br>
  {badges}
<br>
{sns_badges}

</h2>

</p>

>[!IMPORTANT]
>{important_message}

{sections_content}
